export type ExpressMiddleware = import('../../types').ExpressMiddleware;
export type AppConfiguration = import('../../types').AppConfiguration;
export type Controller = import('../../types').Controller;
export type ResponsesBuilder = import('../../services/http/responsesBuilder').ResponsesBuilder;
/**
 * @typedef {import('../../types').ExpressMiddleware} ExpressMiddleware
 * @typedef {import('../../types').AppConfiguration} AppConfiguration
 * @typedef {import('../../types').Controller} Controller
 * @typedef {import('../../services/http/responsesBuilder').ResponsesBuilder} ResponsesBuilder
 * @prettierignore
 */
/**
 * Provides the handler to show a some minimal health information about the app:
 * - app version.
 * - configuration name.
 *
 * @parent module:controllers
 */
export class HealthController {
    /**
     * @param {AppConfiguration} appConfiguration  To read the app version and the
     *                                             configuration name.
     * @param {ResponsesBuilder} responsesBuilder  To generate the JSON response.
     */
    constructor(appConfiguration: AppConfiguration, responsesBuilder: ResponsesBuilder);
    /**
     * A local reference for the `appConfiguration` service.
     *
     * @type {AppConfiguration}
     * @access protected
     * @ignore
     */
    _appConfiguration: AppConfiguration;
    /**
     * A local reference for the `responsesBuilder` service.
     *
     * @type {ResponsesBuilder}
     * @access protected
     * @ignore
     */
    _responsesBuilder: ResponsesBuilder;
    /**
     * Returns the middleware that shows the health information.
     *
     * @returns {ExpressMiddleware}
     */
    health(): ExpressMiddleware;
}
/**
 * Mounts the health route.
 *
 * @type {Controller}
 * @parent module:controllers
 */
export const healthController: Controller;
