export type ExpressMiddleware = import('../../types').ExpressMiddleware;
/**
 * <O>
 */
export type MiddlewareCreator<O> = import('../../types').MiddlewareCreator<O>;
export type ForceHTTPSMiddlewareOptions = {
    /**
     * A list of regular expressions to match routes that
     * should be ignored.
     */
    ignoredRoutes: RegExp[];
};
/**
 * @typedef {import('../../types').ExpressMiddleware} ExpressMiddleware
 */
/**
 * @typedef {import('../../types').MiddlewareCreator<O>} MiddlewareCreator<O>
 * @template O
 */
/**
 * @typedef {Object} ForceHTTPSMiddlewareOptions
 * @property {RegExp[]} ignoredRoutes  A list of regular expressions to match routes that
 *                                     should be ignored.
 * @parent module:middlewares
 */
/**
 * Force all the app traffice to be through HTTPS.
 *
 * @parent module:middlewares
 */
export class ForceHTTPS {
    /**
     * @param {RegExp[]} [ignoredRoutes=[/^\/service\//]]
     * A list of regular expressions to match routes that should be ignored.
     */
    constructor(ignoredRoutes?: RegExp[]);
    /**
     * A list of regular expressions to match routes that should be ignored.
     *
     * @type {RegExp[]}
     * @access protected
     * @ignore
     */
    _ignoredRoutes: RegExp[];
    /**
     * Returns the Express middleware that forces the redirection to HTTPS.
     *
     * @returns {ExpressMiddleware}
     */
    middleware(): ExpressMiddleware;
    /**
     * A list of regular expressions to match routes that should be ignored.
     *
     * @type {RegExp[]}
     */
    get ignoredRoutes(): RegExp[];
}
/**
 * A middleware to force HTTPS redirections to all the routes.
 *
 * @type {MiddlewareCreator<ForceHTTPSMiddlewareOptions>}
 * @parent module:middlewares
 */
export const forceHTTPS: MiddlewareCreator<ForceHTTPSMiddlewareOptions>;
